@@ -98,18 +98,29 @@ class Trace3DList(CustomList):
         super(Trace3DList, self).__init__(TraceIteratorWrapper(iterable))
 
     def to_array(self):
-        self.load()
-        new_list = [list(g) for k, g in itertools.groupby(self, lambda x: x.iline.value)]
+        group_list = self._group_by_inline()
         result = []
-        for inline_group in new_list:
+        for inline_group in group_list:
             result.append(np.array([np.array(i.trace) for i in inline_group]))
         return np.array(result)
 
+    def xy_array(self):
+        group_list = self._group_by_inline()
+        result = []
+        for inline_group in group_list:
+            result.append(np.array([np.array([i.get_x(), i.get_y()]) for i in inline_group]))
+        return np.array(result)
+
+    def _group_by_inline(self):
+        return [list(g) for k, g in itertools.groupby(self.to_list(), lambda x: x.iline.value)]
+
 
 class Trace2DList(CustomList):
     def __init__(self, iterable):
         super(Trace2DList, self).__init__(TraceIteratorWrapper(iterable))
 
     def to_array(self):
-        self.load()
-        return np.array([np.array(t.trace) for t in self])
+        return np.array([np.array(t.trace) for t in self.to_list()])
+
+    def xy_array(self):
+        return np.array([np.array([t.get_x(), t.get_y()]) for t in self.to_list()])
